Index: IntegerProgramming/binomial.cc
===================================================================
--- IntegerProgramming/binomial.cc	(revision 5a60835ee02dcb3d57c9e469c5d50e25ec5d29db)
+++ IntegerProgramming/binomial.cc	(revision 88615dbd0782deeb4def60eef9657a8fa5c30e4d)
@@ -301,5 +301,5 @@
     {
       cerr<<"\nWARNING: binomial& binomial::operator=(const binomial&):\n"
-        "assigment from corrupt binomial"<<endl;
+        "assignment from corrupt binomial"<<endl;
       exponent_vector=NULL;
       return (*this);
Index: IntegerProgramming/binomial.h
===================================================================
--- IntegerProgramming/binomial.h	(revision 5a60835ee02dcb3d57c9e469c5d50e25ec5d29db)
+++ IntegerProgramming/binomial.h	(revision 88615dbd0782deeb4def60eef9657a8fa5c30e4d)
@@ -115,5 +115,5 @@
 
 
-// assigment and access operators
+// assignment and access operators
 
   binomial& operator=(const binomial&);
Index: IntegerProgramming/list.cc
===================================================================
--- IntegerProgramming/list.cc	(revision 5a60835ee02dcb3d57c9e469c5d50e25ec5d29db)
+++ IntegerProgramming/list.cc	(revision 88615dbd0782deeb4def60eef9657a8fa5c30e4d)
@@ -963,5 +963,5 @@
 
 
-////////////////////////// assigment ///////////////////////////////////////
+////////////////////////// assignment ///////////////////////////////////////
 
 
Index: Singular/LIB/grobcov.lib
===================================================================
--- Singular/LIB/grobcov.lib	(revision 5a60835ee02dcb3d57c9e469c5d50e25ec5d29db)
+++ Singular/LIB/grobcov.lib	(revision 88615dbd0782deeb4def60eef9657a8fa5c30e4d)
@@ -3084,5 +3084,5 @@
 //    where the w_l=(n_l1,..,n_ls) are intvec of length size(L), where
 //    n_lt fixes which element of (v_t1,..,v_tk_t) is to be
-//    choosen to form the tth (Q,P) for the lth element of the sheaf
+//    chosen to form the tth (Q,P) for the lth element of the sheaf
 //    representing the I-regular function.
 // The selection is done to obtian the minimal number of elements
Index: Singular/LIB/normal.lib
===================================================================
--- Singular/LIB/normal.lib	(revision 5a60835ee02dcb3d57c9e469c5d50e25ec5d29db)
+++ Singular/LIB/normal.lib	(revision 88615dbd0782deeb4def60eef9657a8fa5c30e4d)
@@ -186,5 +186,5 @@
     if ( typeof(#[i]) == "string" )
     {
-//--------------------------- choosen methods -----------------------
+//--------------------------- chosen methods -----------------------
       if ( (#[i]=="isprim") or (#[i]=="isPrim") )
       {decomp = 0;}
@@ -5725,5 +5725,5 @@
    }
 
-   //--------------------------- choosen methods -----------------------
+   //--------------------------- chosen methods -----------------------
    // "withGens": computes algebra generators for each irreducible component
    // ### the extra code for withGens should be incorporated in the general case
Index: Singular/LIB/surf.lib
===================================================================
--- Singular/LIB/surf.lib	(revision 5a60835ee02dcb3d57c9e469c5d50e25ec5d29db)
+++ Singular/LIB/surf.lib	(revision 88615dbd0782deeb4def60eef9657a8fa5c30e4d)
@@ -177,5 +177,5 @@
     surf_call = "singularsurf ";
     surf_call = surf_call + l + " >/dev/null 2>&1";
-    "Close window to exit from `singularurf`.";
+    "Close window to exit from `singularsurf`.";
 
     i = system("sh", surf_call);
Index: Singular/fevoices.cc
===================================================================
--- Singular/fevoices.cc	(revision 5a60835ee02dcb3d57c9e469c5d50e25ec5d29db)
+++ Singular/fevoices.cc	(revision 88615dbd0782deeb4def60eef9657a8fa5c30e4d)
@@ -88,5 +88,5 @@
 
 /*2
-* init a new voice similiar to the current
+* init a new voice similar to the current
 */
 void Voice::Next()
Index: Singular/fglm.cc
===================================================================
--- Singular/fglm.cc	(revision 5a60835ee02dcb3d57c9e469c5d50e25ec5d29db)
+++ Singular/fglm.cc	(revision 88615dbd0782deeb4def60eef9657a8fa5c30e4d)
@@ -172,5 +172,5 @@
         if ( pperm[k] >= 0 )
         {
-            WerrorS( "paramater names do not agree" );
+            WerrorS( "parameter names do not agree" );
             state= FglmIncompatibleRings;
         }
Index: kernel/GBEngine/kstd1.cc
===================================================================
--- kernel/GBEngine/kstd1.cc	(revision 5a60835ee02dcb3d57c9e469c5d50e25ec5d29db)
+++ kernel/GBEngine/kstd1.cc	(revision 88615dbd0782deeb4def60eef9657a8fa5c30e4d)
@@ -2897,5 +2897,5 @@
                 &olddeg,&reduc,strat, red_result);
 
-      /* reduction of the element choosen from L */
+      /* reduction of the element chosen from L */
       red_result = strat->red(&strat->P,strat);
     }
Index: kernel/GBEngine/kstd2.cc
===================================================================
--- kernel/GBEngine/kstd2.cc	(revision 5a60835ee02dcb3d57c9e469c5d50e25ec5d29db)
+++ kernel/GBEngine/kstd2.cc	(revision 88615dbd0782deeb4def60eef9657a8fa5c30e4d)
@@ -1473,5 +1473,5 @@
                 &olddeg,&reduc,strat, red_result);
 
-      /* reduction of the element choosen from L */
+      /* reduction of the element chosen from L */
       red_result = strat->red(&strat->P,strat);
       if (errorreported)  break;
@@ -1836,5 +1836,5 @@
     strat->P = strat->L[strat->Ll];
     strat->Ll--;
-    /* reduction of the element choosen from L */
+    /* reduction of the element chosen from L */
 
     if (!strat->rewCrit2(strat->P.sig, ~strat->P.sevSig, strat->P.GetLmCurrRing(), strat, strat->P.checked+1)) {
@@ -2677,5 +2677,5 @@
       pWrite(strat->P.p);
 #endif
-      /* complete reduction of the element choosen from L */
+      /* complete reduction of the element chosen from L */
       red_result = strat->red2(&strat->P,strat);
       if (errorreported)  break;
@@ -3012,5 +3012,5 @@
                 &olddeg,&reduc,strat, red_result);
 
-      /* reduction of the element choosen from L */
+      /* reduction of the element chosen from L */
       red_result = strat->red(&strat->P,strat);
     }
Index: kernel/GBEngine/kstdfac.cc
===================================================================
--- kernel/GBEngine/kstdfac.cc	(revision 5a60835ee02dcb3d57c9e469c5d50e25ec5d29db)
+++ kernel/GBEngine/kstdfac.cc	(revision 88615dbd0782deeb4def60eef9657a8fa5c30e4d)
@@ -589,5 +589,5 @@
         message(currRing->pFDeg(strat->P.p,currRing),&olddeg,&reduc,strat, red_result);
     }
-    /* reduction of the element choosen from L */
+    /* reduction of the element chosen from L */
     kTest_TS(strat);
     red_result = strat->red(&strat->P,strat);
Index: kernel/GBEngine/sca.cc
===================================================================
--- kernel/GBEngine/sca.cc	(revision 5a60835ee02dcb3d57c9e469c5d50e25ec5d29db)
+++ kernel/GBEngine/sca.cc	(revision 88615dbd0782deeb4def60eef9657a8fa5c30e4d)
@@ -615,5 +615,5 @@
               &olddeg,&reduc,strat, red_result);
 
-    // reduction of the element choosen from L
+    // reduction of the element chosen from L
     red_result = strat->red(&strat->P,strat);
 
@@ -743,5 +743,5 @@
         h.PrepareRed(strat->use_buckets);
 
-        // reduction of the element choosen from L(?)
+        // reduction of the element chosen from L(?)
         red_result = strat->red(&h,strat);
 
Index: kernel/fast_mult.cc
===================================================================
--- kernel/fast_mult.cc	(revision 5a60835ee02dcb3d57c9e469c5d50e25ec5d29db)
+++ kernel/fast_mult.cc	(revision 88615dbd0782deeb4def60eef9657a8fa5c30e4d)
@@ -592,5 +592,5 @@
     Werror("not implemented for so small n, recursion fails");//should be length(f)
    if (pLength(f)<=1)
-    Werror("not implemented for so small lenght of f, recursion fails");
+    Werror("not implemented for so small length of f, recursion fails");
   //  number null_number=n_Init(0,r);
   number* facult=(number*) omAlloc((n+1)*sizeof(number));
Index: kernel/groebner_walk/walkProc.cc
===================================================================
--- kernel/groebner_walk/walkProc.cc	(revision 5a60835ee02dcb3d57c9e469c5d50e25ec5d29db)
+++ kernel/groebner_walk/walkProc.cc	(revision 88615dbd0782deeb4def60eef9657a8fa5c30e4d)
@@ -118,5 +118,5 @@
         if ( pperm[k] >= 0 )
         {
-            WerrorS( "paramater names do not agree" );
+            WerrorS( "parameter names do not agree" );
             state= WalkIncompatibleRings;
         }
Index: kernel/numeric/mpr_inout.cc
===================================================================
--- kernel/numeric/mpr_inout.cc	(revision 5a60835ee02dcb3d57c9e469c5d50e25ec5d29db)
+++ kernel/numeric/mpr_inout.cc	(revision 88615dbd0782deeb4def60eef9657a8fa5c30e4d)
@@ -63,5 +63,5 @@
   {
   case mprWrongRType:
-    WerrorS("Unknown resultant matrix type choosen!");
+    WerrorS("Unknown chosen resultant matrix type!");
     break;
   case mprHasOne:
Index: libpolys/coeffs/Enumerator.h
===================================================================
--- libpolys/coeffs/Enumerator.h	(revision 5a60835ee02dcb3d57c9e469c5d50e25ec5d29db)
+++ libpolys/coeffs/Enumerator.h	(revision 88615dbd0782deeb4def60eef9657a8fa5c30e4d)
@@ -58,5 +58,5 @@
 
   private:
-    /// disable copy constructor and assigment operator
+    /// disable copy constructor and assignment operator
     IBaseEnumerator(const IBaseEnumerator&);
     void operator=(const IBaseEnumerator&);
@@ -169,5 +169,5 @@
 /** @class AIterator
  *
- * An abstract iterator with virtualized assigment operator and
+ * An abstract iterator with virtualized assignment operator and
  * constructors.
  *
Index: libpolys/coeffs/longrat.cc
===================================================================
--- libpolys/coeffs/longrat.cc	(revision 5a60835ee02dcb3d57c9e469c5d50e25ec5d29db)
+++ libpolys/coeffs/longrat.cc	(revision 88615dbd0782deeb4def60eef9657a8fa5c30e4d)
@@ -3086,5 +3086,5 @@
 {
   /* test, if r is an instance of nInitCoeffs(n,parameter) */
-  /* if paramater is not needed */
+  /* if parameter is not needed */
   if (n==r->type)
   {
Index: libpolys/coeffs/numbers.cc
===================================================================
--- libpolys/coeffs/numbers.cc	(revision 5a60835ee02dcb3d57c9e469c5d50e25ec5d29db)
+++ libpolys/coeffs/numbers.cc	(revision 88615dbd0782deeb4def60eef9657a8fa5c30e4d)
@@ -277,5 +277,5 @@
 {
   /* test, if r is an instance of nInitCoeffs(n,parameter) */
-  /* if paramater is not needed */
+  /* if parameter is not needed */
   return (n==r->type);
 }
Index: libpolys/polys/templates/p_Procs_Impl.h
===================================================================
--- libpolys/polys/templates/p_Procs_Impl.h	(revision 5a60835ee02dcb3d57c9e469c5d50e25ec5d29db)
+++ libpolys/polys/templates/p_Procs_Impl.h	(revision 88615dbd0782deeb4def60eef9657a8fa5c30e4d)
@@ -31,6 +31,6 @@
  macros.
 
- At run-time, a fast proc is set/choosen if found/generated, else
- a general proc is set/choosen.
+ At run-time, a fast proc is set/chosen if found/generated, else
+ a general proc is set/chosen.
  *******************************************************************/
 
@@ -396,5 +396,5 @@
  *
  * Filters which are applied to field/length/ord, before a proc is
- * choosen
+ * chosen
  *
  *******************************************************************/

Index: Singular/ipassign.cc
===================================================================
--- Singular/ipassign.cc	(revision 5a60835ee02dcb3d57c9e469c5d50e25ec5d29db)
+++ Singular/ipassign.cc	(revision 88615dbd0782deeb4def60eef9657a8fa5c30e4d)
@@ -1698,5 +1698,5 @@
       if(like_lists)
       {
-        if (traceit&TRACE_ASSIGN) PrintS("assign list[..]=...or similiar\n");
+        if (traceit&TRACE_ASSIGN) PrintS("assign list[..]=...or similar\n");
         if (like_lists==1)
         {
@@ -1734,5 +1734,5 @@
       return (bb==NULL) || bb->blackbox_Assign(l,r);
     }
     // end of handling elems of list and similiar
     rl=r->listLength();
     if (rl==1)
@@ -1734,5 +1734,5 @@
       return (bb==NULL) || bb->blackbox_Assign(l,r);
     }
-    // end of handling elems of list and similiar
+    // end of handling elems of list and similar
     rl=r->listLength();
     if (rl==1)
Index: kernel/numeric/mpr_base.cc
===================================================================
--- kernel/numeric/mpr_base.cc	(revision 5a60835ee02dcb3d57c9e469c5d50e25ec5d29db)
+++ kernel/numeric/mpr_base.cc	(revision 88615dbd0782deeb4def60eef9657a8fa5c30e4d)
@@ -1458,5 +1458,5 @@
       {
         // this can happen, if the shift vektor or the lift funktions
         // are not generically choosen.
         Werror("resMatrixSparse::createMatrix: Found exponent not in E, id %d, set [%d, %d]!",
                i,(*E)[i]->rc.set,(*E)[i]->rc.pnt);
@@ -2704,5 +2704,5 @@
     break;
   default:
-    WerrorS("uResultant::uResultant: Unknown resultant matrix type choosen!");
+    WerrorS("uResultant::uResultant: Unknown chosen resultant matrix type!");
   }
 }
@@ -2735,5 +2735,5 @@
     break;
   default:
-    WerrorS("uResultant::extendIdeal: Unknown resultant matrix type choosen!");
+    WerrorS("uResultant::extendIdeal: Unknown chosen resultant matrix type!");
   }
 
@@ -1458,5 +1458,5 @@
       {
         // this can happen, if the shift vektor or the lift funktions
-        // are not generically choosen.
+        // are not generically chosen.
         Werror("resMatrixSparse::createMatrix: Found exponent not in E, id %d, set [%d, %d]!",
                i,(*E)[i]->rc.set,(*E)[i]->rc.pnt);